==> gorilla-notes-0.3.0-20200818.200253-6.jar: public/js/compiled/cljs-runtime/module$node_modules$react_draggable$build$cjs$Draggable.js <==
shadow$provide.module$node_modules$react_draggable$build$cjs$Draggable=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:
function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;
for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),
!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&
(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,
{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _createSuper(Derived){var hasNativeReflectConstruct=_isNativeReflectConstruct();return function(){var Super=_getPrototypeOf(Derived);if(hasNativeReflectConstruct){var NewTarget=_getPrototypeOf(this).constructor;Super=
Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;
try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value:value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});
Object.defineProperty(exports,"DraggableCore",{enumerable:!0,get:function(){return _DraggableCore.default}});exports.default=void 0;var React=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{default:obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,
key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj.default=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index"));global=_interopRequireDefault(require("module$node_modules$prop_types$index"));var _reactDom=_interopRequireDefault(require("module$node_modules$react_dom$index")),_classnames=_interopRequireDefault(require("module$node_modules$classnames$index")),
_domFns=require("module$node_modules$react_draggable$build$cjs$utils$domFns"),_positionFns=require("module$node_modules$react_draggable$build$cjs$utils$positionFns");module=require("module$node_modules$react_draggable$build$cjs$utils$shims");var _DraggableCore=_interopRequireDefault(require("module$node_modules$react_draggable$build$cjs$DraggableCore")),_log=_interopRequireDefault(require("module$node_modules$react_draggable$build$cjs$utils$log"));require=function(_React$Component){function Draggable(props){if(!(this instanceof
Draggable))throw new TypeError("Cannot call a class as a function");var _this=_super.call(this,props);_defineProperty(_assertThisInitialized(_this),"onDragStart",function(e,coreData){(0,_log.default)("Draggable: onDragStart: %j",coreData);if(!1===_this.props.onStart(e,(0,_positionFns.createDraggableData)(_assertThisInitialized(_this),coreData)))return!1;_this.setState({dragging:!0,dragged:!0})});_defineProperty(_assertThisInitialized(_this),"onDrag",function(e,coreData){if(!_this.state.dragging)return!1;
(0,_log.default)("Draggable: onDrag: %j",coreData);coreData=(0,_positionFns.createDraggableData)(_assertThisInitialized(_this),coreData);var newState={x:coreData.x,y:coreData.y};if(_this.props.bounds){var x=newState.x,y=newState.y;newState.x+=_this.state.slackX;newState.y+=_this.state.slackY;var arr=(0,_positionFns.getBoundPosition)(_assertThisInitialized(_this),newState.x,newState.y);var JSCompiler_temp=Array.isArray(arr)?arr:void 0;if(!JSCompiler_temp)if("undefined"!==typeof Symbol&&Symbol.iterator in
Object(arr)){JSCompiler_temp=[];var _n=!0,_d=!1,_e=void 0;try{var JSCompiler_temp$jscomp$0=arr[Symbol.iterator]();for(var _s;!(_n=(_s=JSCompiler_temp$jscomp$0.next()).done)&&(JSCompiler_temp.push(_s.value),2!==JSCompiler_temp.length);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=JSCompiler_temp$jscomp$0["return"])JSCompiler_temp$jscomp$0["return"]()}finally{if(_d)throw _e;}}}else JSCompiler_temp=void 0;if(!(JSCompiler_temp$jscomp$0=JSCompiler_temp))a:{if(arr){if("string"===typeof arr){JSCompiler_temp$jscomp$0=
_arrayLikeToArray(arr,2);break a}JSCompiler_temp$jscomp$0=Object.prototype.toString.call(arr).slice(8,-1);"Object"===JSCompiler_temp$jscomp$0&&arr.constructor&&(JSCompiler_temp$jscomp$0=arr.constructor.name);if("Map"===JSCompiler_temp$jscomp$0||"Set"===JSCompiler_temp$jscomp$0){JSCompiler_temp$jscomp$0=Array.from(arr);break a}if("Arguments"===JSCompiler_temp$jscomp$0||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(JSCompiler_temp$jscomp$0)){JSCompiler_temp$jscomp$0=_arrayLikeToArray(arr,2);break a}}JSCompiler_temp$jscomp$0=
void 0}if(!(arr=JSCompiler_temp$jscomp$0))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");JSCompiler_temp$jscomp$0=arr[1];newState.x=arr[0];newState.y=JSCompiler_temp$jscomp$0;newState.slackX=_this.state.slackX+(x-newState.x);newState.slackY=_this.state.slackY+(y-newState.y);coreData.x=newState.x;coreData.y=newState.y;coreData.deltaX=newState.x-_this.state.x;coreData.deltaY=newState.y-
_this.state.y}if(!1===_this.props.onDrag(e,coreData))return!1;_this.setState(newState)});_defineProperty(_assertThisInitialized(_this),"onDragStop",function(e,coreData){if(!_this.state.dragging||!1===_this.props.onStop(e,(0,_positionFns.createDraggableData)(_assertThisInitialized(_this),coreData)))return!1;(0,_log.default)("Draggable: onDragStop: %j",coreData);e={dragging:!1,slackX:0,slackY:0};if(_this.props.position){coreData=_this.props.position;var y=coreData.y;e.x=coreData.x;e.y=y}_this.setState(e)});
_this.state={dragging:!1,dragged:!1,x:props.position?props.position.x:props.defaultPosition.x,y:props.position?props.position.y:props.defaultPosition.y,prevPropsPosition:_objectSpread({},props.position),slackX:0,slackY:0,isElementSVG:!1};!props.position||props.onDrag||props.onStop||console.warn("A `position` was applied to this \x3cDraggable\x3e, without drag handlers. This will make this component effectively undraggable. Please attach `onDrag` or `onStop` handlers so you can adjust the `position` of this element.");
return _this}_inherits(Draggable,_React$Component);var _super=_createSuper(Draggable);_createClass(Draggable,null,[{key:"getDerivedStateFromProps",value:function(_ref,_ref2){_ref=_ref.position;_ref2=_ref2.prevPropsPosition;return!_ref||_ref2&&_ref.x===_ref2.x&&_ref.y===_ref2.y?null:((0,_log.default)("Draggable: getDerivedStateFromProps %j",{position:_ref,prevPropsPosition:_ref2}),{x:_ref.x,y:_ref.y,prevPropsPosition:_objectSpread({},_ref)})}}]);_createClass(Draggable,[{key:"componentDidMount",value:function(){"undefined"!==
typeof window.SVGElement&&this.findDOMNode()instanceof window.SVGElement&&this.setState({isElementSVG:!0})}},{key:"componentWillUnmount",value:function(){this.setState({dragging:!1})}},{key:"findDOMNode",value:function(){return this.props.nodeRef?this.props.nodeRef.current:_reactDom.default.findDOMNode(this)}},{key:"render",value:function(){var _classNames,_this$props=this.props,children=_this$props.children,defaultPosition=_this$props.defaultPosition,defaultClassName=_this$props.defaultClassName,
defaultClassNameDragging=_this$props.defaultClassNameDragging,defaultClassNameDragged=_this$props.defaultClassNameDragged,position=_this$props.position,positionOffset=_this$props.positionOffset;var excluded="axis bounds children defaultPosition defaultClassName defaultClassNameDragging defaultClassNameDragged position positionOffset scale".split(" ");if(null==_this$props)_this$props={};else{if(null==_this$props)var target={};else{target={};var sourceKeys=Object.keys(_this$props),i;for(i=0;i<sourceKeys.length;i++){var key=
sourceKeys[i];0<=excluded.indexOf(key)||(target[key]=_this$props[key])}}if(Object.getOwnPropertySymbols)for(i=Object.getOwnPropertySymbols(_this$props),key=0;key<i.length;key++)sourceKeys=i[key],0<=excluded.indexOf(sourceKeys)||Object.prototype.propertyIsEnumerable.call(_this$props,sourceKeys)&&(target[sourceKeys]=_this$props[sourceKeys]);_this$props=target}excluded={};target=null;sourceKeys=!position||this.state.dragging;defaultPosition=position||defaultPosition;defaultPosition={x:(0,_positionFns.canDragX)(this)&&
sourceKeys?this.state.x:defaultPosition.x,y:(0,_positionFns.canDragY)(this)&&sourceKeys?this.state.y:defaultPosition.y};this.state.isElementSVG?target=(0,_domFns.createSVGTransform)(defaultPosition,positionOffset):excluded=(0,_domFns.createCSSTransform)(defaultPosition,positionOffset);defaultClassName=(0,_classnames.default)(children.props.className||"",defaultClassName,(_classNames={},_defineProperty(_classNames,defaultClassNameDragging,this.state.dragging),_defineProperty(_classNames,defaultClassNameDragged,
this.state.dragged),_classNames));return React.createElement(_DraggableCore.default,_extends({},_this$props,{onStart:this.onDragStart,onDrag:this.onDrag,onStop:this.onDragStop}),React.cloneElement(React.Children.only(children),{className:defaultClassName,style:_objectSpread(_objectSpread({},children.props.style),excluded),transform:target}))}}]);return Draggable}(React.Component);exports.default=require;_defineProperty(require,"displayName","Draggable");_defineProperty(require,"propTypes",_objectSpread(_objectSpread({},
_DraggableCore.default.propTypes),{},{axis:global.default.oneOf(["both","x","y","none"]),bounds:global.default.oneOfType([global.default.shape({left:global.default.number,right:global.default.number,top:global.default.number,bottom:global.default.number}),global.default.string,global.default.oneOf([!1])]),defaultClassName:global.default.string,defaultClassNameDragging:global.default.string,defaultClassNameDragged:global.default.string,defaultPosition:global.default.shape({x:global.default.number,
y:global.default.number}),positionOffset:global.default.shape({x:global.default.oneOfType([global.default.number,global.default.string]),y:global.default.oneOfType([global.default.number,global.default.string])}),position:global.default.shape({x:global.default.number,y:global.default.number}),className:module.dontSetMe,style:module.dontSetMe,transform:module.dontSetMe}));_defineProperty(require,"defaultProps",_objectSpread(_objectSpread({},_DraggableCore.default.defaultProps),{},{axis:"both",bounds:!1,
defaultClassName:"react-draggable",defaultClassNameDragging:"react-draggable-dragging",defaultClassNameDragged:"react-draggable-dragged",defaultPosition:{x:0,y:0},position:null,scale:1}))}
//# sourceMappingURL=module$node_modules$react_draggable$build$cjs$Draggable.js.map

==> gorilla-notes-0.4.0.jar: public/js/compiled/cljs-runtime/module$node_modules$react_draggable$build$cjs$Draggable.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$react_draggable$build$cjs$Draggable=function(global,require,module,exports){function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{default:obj}}function _getRequireWildcardCache(){if("function"!==typeof WeakMap)return null;var cache=new WeakMap;_getRequireWildcardCache=function(){return cache};return cache}function _typeof(obj$jscomp$0){"@babel/helpers - typeof";_typeof="function"===typeof Symbol&&"symbol"===typeof Symbol.iterator?function(obj){return typeof obj}:
function(obj){return obj&&"function"===typeof Symbol&&obj.constructor===Symbol&&obj!==Symbol.prototype?"symbol":typeof obj};return _typeof(obj$jscomp$0)}function _extends(){_extends=Object.assign||function(target){for(var i=1;i<arguments.length;i++){var source=arguments[i],key;for(key in source)Object.prototype.hasOwnProperty.call(source,key)&&(target[key]=source[key])}return target};return _extends.apply(this,arguments)}function _arrayLikeToArray(arr,len){if(null==len||len>arr.length)len=arr.length;
for(var i=0,arr2=Array(len);i<len;i++)arr2[i]=arr[i];return arr2}function ownKeys(object,enumerableOnly){var keys=Object.keys(object);if(Object.getOwnPropertySymbols){var symbols=Object.getOwnPropertySymbols(object);enumerableOnly&&(symbols=symbols.filter(function(sym){return Object.getOwnPropertyDescriptor(object,sym).enumerable}));keys.push.apply(keys,symbols)}return keys}function _objectSpread(target){for(var i=1;i<arguments.length;i++){var source=null!=arguments[i]?arguments[i]:{};i%2?ownKeys(Object(source),
!0).forEach(function(key){_defineProperty(target,key,source[key])}):Object.getOwnPropertyDescriptors?Object.defineProperties(target,Object.getOwnPropertyDescriptors(source)):ownKeys(Object(source)).forEach(function(key){Object.defineProperty(target,key,Object.getOwnPropertyDescriptor(source,key))})}return target}function _defineProperties(target,props){for(var i=0;i<props.length;i++){var descriptor=props[i];descriptor.enumerable=descriptor.enumerable||!1;descriptor.configurable=!0;"value"in descriptor&&
(descriptor.writable=!0);Object.defineProperty(target,descriptor.key,descriptor)}}function _createClass(Constructor,protoProps,staticProps){protoProps&&_defineProperties(Constructor.prototype,protoProps);staticProps&&_defineProperties(Constructor,staticProps);return Constructor}function _inherits(subClass,superClass){if("function"!==typeof superClass&&null!==superClass)throw new TypeError("Super expression must either be null or a function");subClass.prototype=Object.create(superClass&&superClass.prototype,
{constructor:{value:subClass,writable:!0,configurable:!0}});superClass&&_setPrototypeOf(subClass,superClass)}function _setPrototypeOf(o$jscomp$0,p$jscomp$0){_setPrototypeOf=Object.setPrototypeOf||function(o,p){o.__proto__=p;return o};return _setPrototypeOf(o$jscomp$0,p$jscomp$0)}function _createSuper(Derived){var hasNativeReflectConstruct=_isNativeReflectConstruct();return function(){var Super=_getPrototypeOf(Derived);if(hasNativeReflectConstruct){var NewTarget=_getPrototypeOf(this).constructor;Super=
Reflect.construct(Super,arguments,NewTarget)}else Super=Super.apply(this,arguments);Super=!Super||"object"!==_typeof(Super)&&"function"!==typeof Super?_assertThisInitialized(this):Super;return Super}}function _assertThisInitialized(self){if(void 0===self)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return self}function _isNativeReflectConstruct(){if("undefined"===typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"===typeof Proxy)return!0;
try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(e){return!1}}function _getPrototypeOf(o$jscomp$0){_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(o){return o.__proto__||Object.getPrototypeOf(o)};return _getPrototypeOf(o$jscomp$0)}function _defineProperty(obj,key,value){key in obj?Object.defineProperty(obj,key,{value,enumerable:!0,configurable:!0,writable:!0}):obj[key]=value;return obj}Object.defineProperty(exports,"__esModule",{value:!0});
Object.defineProperty(exports,"DraggableCore",{enumerable:!0,get:function(){return _DraggableCore.default}});exports.default=void 0;var React=function(obj){if(obj&&obj.__esModule)return obj;if(null===obj||"object"!==_typeof(obj)&&"function"!==typeof obj)return{default:obj};var cache=_getRequireWildcardCache();if(cache&&cache.has(obj))return cache.get(obj);var newObj={},hasPropertyDescriptor=Object.defineProperty&&Object.getOwnPropertyDescriptor,key;for(key in obj)if(Object.prototype.hasOwnProperty.call(obj,
key)){var desc=hasPropertyDescriptor?Object.getOwnPropertyDescriptor(obj,key):null;desc&&(desc.get||desc.set)?Object.defineProperty(newObj,key,desc):newObj[key]=obj[key]}newObj.default=obj;cache&&cache.set(obj,newObj);return newObj}(require("module$node_modules$react$index"));global=_interopRequireDefault(require("module$node_modules$prop_types$index"));var _reactDom=_interopRequireDefault(require("module$node_modules$react_dom$index")),_classnames=_interopRequireDefault(require("module$node_modules$classnames$index")),
_domFns=require("module$node_modules$react_draggable$build$cjs$utils$domFns"),_positionFns=require("module$node_modules$react_draggable$build$cjs$utils$positionFns");module=require("module$node_modules$react_draggable$build$cjs$utils$shims");var _DraggableCore=_interopRequireDefault(require("module$node_modules$react_draggable$build$cjs$DraggableCore")),_log=_interopRequireDefault(require("module$node_modules$react_draggable$build$cjs$utils$log"));require=function(_React$Component){function Draggable(props){if(!(this instanceof
Draggable))throw new TypeError("Cannot call a class as a function");var _this=_super.call(this,props);_defineProperty(_assertThisInitialized(_this),"onDragStart",function(e,coreData){(0,_log.default)("Draggable: onDragStart: %j",coreData);if(!1===_this.props.onStart(e,(0,_positionFns.createDraggableData)(_assertThisInitialized(_this),coreData)))return!1;_this.setState({dragging:!0,dragged:!0})});_defineProperty(_assertThisInitialized(_this),"onDrag",function(e,coreData){if(!_this.state.dragging)return!1;
(0,_log.default)("Draggable: onDrag: %j",coreData);coreData=(0,_positionFns.createDraggableData)(_assertThisInitialized(_this),coreData);var newState={x:coreData.x,y:coreData.y};if(_this.props.bounds){var x=newState.x,y=newState.y;newState.x+=_this.state.slackX;newState.y+=_this.state.slackY;var arr=(0,_positionFns.getBoundPosition)(_assertThisInitialized(_this),newState.x,newState.y);var JSCompiler_temp=Array.isArray(arr)?arr:void 0;if(!JSCompiler_temp)if("undefined"!==typeof Symbol&&Symbol.iterator in
Object(arr)){JSCompiler_temp=[];var _n=!0,_d=!1,_e=void 0;try{var JSCompiler_temp$jscomp$0=arr[Symbol.iterator]();for(var _s;!(_n=(_s=JSCompiler_temp$jscomp$0.next()).done)&&(JSCompiler_temp.push(_s.value),2!==JSCompiler_temp.length);_n=!0);}catch(err){_d=!0,_e=err}finally{try{if(!_n&&null!=JSCompiler_temp$jscomp$0["return"])JSCompiler_temp$jscomp$0["return"]()}finally{if(_d)throw _e;}}}else JSCompiler_temp=void 0;if(!(JSCompiler_temp$jscomp$0=JSCompiler_temp))a:{if(arr){if("string"===typeof arr){JSCompiler_temp$jscomp$0=
_arrayLikeToArray(arr,2);break a}JSCompiler_temp$jscomp$0=Object.prototype.toString.call(arr).slice(8,-1);"Object"===JSCompiler_temp$jscomp$0&&arr.constructor&&(JSCompiler_temp$jscomp$0=arr.constructor.name);if("Map"===JSCompiler_temp$jscomp$0||"Set"===JSCompiler_temp$jscomp$0){JSCompiler_temp$jscomp$0=Array.from(arr);break a}if("Arguments"===JSCompiler_temp$jscomp$0||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(JSCompiler_temp$jscomp$0)){JSCompiler_temp$jscomp$0=_arrayLikeToArray(arr,2);break a}}JSCompiler_temp$jscomp$0=
void 0}if(!(arr=JSCompiler_temp$jscomp$0))throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");JSCompiler_temp$jscomp$0=arr[1];newState.x=arr[0];newState.y=JSCompiler_temp$jscomp$0;newState.slackX=_this.state.slackX+(x-newState.x);newState.slackY=_this.state.slackY+(y-newState.y);coreData.x=newState.x;coreData.y=newState.y;coreData.deltaX=newState.x-_this.state.x;coreData.deltaY=newState.y-
_this.state.y}if(!1===_this.props.onDrag(e,coreData))return!1;_this.setState(newState)});_defineProperty(_assertThisInitialized(_this),"onDragStop",function(e,coreData){if(!_this.state.dragging||!1===_this.props.onStop(e,(0,_positionFns.createDraggableData)(_assertThisInitialized(_this),coreData)))return!1;(0,_log.default)("Draggable: onDragStop: %j",coreData);e={dragging:!1,slackX:0,slackY:0};if(_this.props.position){coreData=_this.props.position;var y=coreData.y;e.x=coreData.x;e.y=y}_this.setState(e)});
_this.state={dragging:!1,dragged:!1,x:props.position?props.position.x:props.defaultPosition.x,y:props.position?props.position.y:props.defaultPosition.y,prevPropsPosition:_objectSpread({},props.position),slackX:0,slackY:0,isElementSVG:!1};!props.position||props.onDrag||props.onStop||console.warn("A `position` was applied to this \x3cDraggable\x3e, without drag handlers. This will make this component effectively undraggable. Please attach `onDrag` or `onStop` handlers so you can adjust the `position` of this element.");
return _this}_inherits(Draggable,_React$Component);var _super=_createSuper(Draggable);_createClass(Draggable,null,[{key:"getDerivedStateFromProps",value:function(_ref,_ref2){_ref=_ref.position;_ref2=_ref2.prevPropsPosition;return!_ref||_ref2&&_ref.x===_ref2.x&&_ref.y===_ref2.y?null:((0,_log.default)("Draggable: getDerivedStateFromProps %j",{position:_ref,prevPropsPosition:_ref2}),{x:_ref.x,y:_ref.y,prevPropsPosition:_objectSpread({},_ref)})}}]);_createClass(Draggable,[{key:"componentDidMount",value:function(){"undefined"!==
typeof window.SVGElement&&this.findDOMNode()instanceof window.SVGElement&&this.setState({isElementSVG:!0})}},{key:"componentWillUnmount",value:function(){this.setState({dragging:!1})}},{key:"findDOMNode",value:function(){return this.props.nodeRef?this.props.nodeRef.current:_reactDom.default.findDOMNode(this)}},{key:"render",value:function(){var _classNames,_this$props=this.props,children=_this$props.children,defaultPosition=_this$props.defaultPosition,defaultClassName=_this$props.defaultClassName,
defaultClassNameDragging=_this$props.defaultClassNameDragging,defaultClassNameDragged=_this$props.defaultClassNameDragged,position=_this$props.position,positionOffset=_this$props.positionOffset;var excluded="axis bounds children defaultPosition defaultClassName defaultClassNameDragging defaultClassNameDragged position positionOffset scale".split(" ");if(null==_this$props)_this$props={};else{if(null==_this$props)var target={};else{target={};var sourceKeys=Object.keys(_this$props),i;for(i=0;i<sourceKeys.length;i++){var key=
sourceKeys[i];0<=excluded.indexOf(key)||(target[key]=_this$props[key])}}if(Object.getOwnPropertySymbols)for(i=Object.getOwnPropertySymbols(_this$props),key=0;key<i.length;key++)sourceKeys=i[key],0<=excluded.indexOf(sourceKeys)||Object.prototype.propertyIsEnumerable.call(_this$props,sourceKeys)&&(target[sourceKeys]=_this$props[sourceKeys]);_this$props=target}excluded={};target=null;sourceKeys=!position||this.state.dragging;defaultPosition=position||defaultPosition;defaultPosition={x:(0,_positionFns.canDragX)(this)&&
sourceKeys?this.state.x:defaultPosition.x,y:(0,_positionFns.canDragY)(this)&&sourceKeys?this.state.y:defaultPosition.y};this.state.isElementSVG?target=(0,_domFns.createSVGTransform)(defaultPosition,positionOffset):excluded=(0,_domFns.createCSSTransform)(defaultPosition,positionOffset);defaultClassName=(0,_classnames.default)(children.props.className||"",defaultClassName,(_classNames={},_defineProperty(_classNames,defaultClassNameDragging,this.state.dragging),_defineProperty(_classNames,defaultClassNameDragged,
this.state.dragged),_classNames));return React.createElement(_DraggableCore.default,_extends({},_this$props,{onStart:this.onDragStart,onDrag:this.onDrag,onStop:this.onDragStop}),React.cloneElement(React.Children.only(children),{className:defaultClassName,style:_objectSpread(_objectSpread({},children.props.style),excluded),transform:target}))}}]);return Draggable}(React.Component);exports.default=require;_defineProperty(require,"displayName","Draggable");_defineProperty(require,"propTypes",_objectSpread(_objectSpread({},
_DraggableCore.default.propTypes),{},{axis:global.default.oneOf(["both","x","y","none"]),bounds:global.default.oneOfType([global.default.shape({left:global.default.number,right:global.default.number,top:global.default.number,bottom:global.default.number}),global.default.string,global.default.oneOf([!1])]),defaultClassName:global.default.string,defaultClassNameDragging:global.default.string,defaultClassNameDragged:global.default.string,defaultPosition:global.default.shape({x:global.default.number,
y:global.default.number}),positionOffset:global.default.shape({x:global.default.oneOfType([global.default.number,global.default.string]),y:global.default.oneOfType([global.default.number,global.default.string])}),position:global.default.shape({x:global.default.number,y:global.default.number}),className:module.dontSetMe,style:module.dontSetMe,transform:module.dontSetMe}));_defineProperty(require,"defaultProps",_objectSpread(_objectSpread({},_DraggableCore.default.defaultProps),{},{axis:"both",bounds:!1,
defaultClassName:"react-draggable",defaultClassNameDragging:"react-draggable-dragging",defaultClassNameDragged:"react-draggable-dragged",defaultPosition:{x:0,y:0},position:null,scale:1}))}
//# sourceMappingURL=module$node_modules$react_draggable$build$cjs$Draggable.js.map
